@@ -2,6 +2,7 @@ class ExploreMixin:
     """
     Helpers for the explore page
     """
+
     def explore_page(self):
         """
         Get explore page
@@ -26,8 +27,19 @@ class ExploreMixin:
             True if success
         """
         params = {
-            'm_pk': media_pk,
+            "m_pk": media_pk,
         }
         result = self.private_request("discover/explore_report/", params=params)
-        return result['explore_report_status'] == "OK"
+        return result["explore_report_status"] == "OK"
 
+    def explore_page_media_info(self, media_pk: int):
+        """
+        Returns media information for a media item on the explore page
+
+        This is the API call that happens when you're on the explore page
+        and you click into a media item. It returns information about that media item
+        like comments, likes, etc.
+        """
+        return self.private_request(
+            "/v1/discover/media_metadata/", params={"media_id": media_pk}
+        )["media_or_ad"]
